@@ -22,7 +22,7 @@ ces <- function(data, seasonality=c("none","simple","partial","full"),
     list2env(list(...),environment());
 
     # If a previous model provided as a model, write down the variables
-    if(exists("model")){
+    if(exists("model",inherits=FALSE)){
         if(is.null(model$model)){
             stop("The provided model is not CES.",call.=FALSE);
         }
