@@ -1,7 +1,7 @@
 sim.ces <- function(seasonality=c("none","simple","partial","full"),
                     frequency=1, A=NULL, B=NULL,
                     initial=NULL,
-                    obs=10, nsim=1, silent=FALSE,
+                    obs=10, nsim=1,
                     randomizer=c("rnorm","runif","rbeta","rt"),
                     iprob=1, ...){
 # Function simulates the data using CES state-space framework
@@ -13,12 +13,13 @@ sim.ces <- function(seasonality=c("none","simple","partial","full"),
 #    If NULL it will be generated.
 # obs - the number of observations in each time series.
 # nsim - the number of series needed to be generated.
-# silent - if TRUE no output is given.
 # randomizer - the type of the random number generator function
 # ... - the parameters passed to the randomizer.
 
     randomizer <- randomizer[1];
 
+    args <- list(...);
+
     AGenerator <- function(nsim=nsim){
         AValue <- matrix(NA,2,nsim);
         ANonStable <- rep(TRUE,nsim);
@@ -221,15 +222,13 @@ sim.ces <- function(seasonality=c("none","simple","partial","full"),
     }
 
 # If the chosen randomizer is not rnorm, rt and runif and no parameters are provided, change to rnorm.
-    if(all(randomizer!=c("rnorm","rlnorm","rt","runif")) & (any(names(match.call(expand.dots=FALSE)[-1]) == "...")==FALSE)){
-        if(silent == FALSE){
-            warning(paste0("The chosen randomizer - ",randomizer," - needs some arbitrary parameters! Changing to 'rnorm' now."),call.=FALSE);
-        }
+    if(all(randomizer!=c("rnorm","rlnorm","rt","runif")) & (length(args)==0)){
+        warning(paste0("The chosen randomizer - ",randomizer," - needs some arbitrary parameters! Changing to 'rnorm' now."),call.=FALSE);
         randomizer = "rnorm";
     }
 
 # Check if no argument was passed in dots
-    if(any(names(match.call(expand.dots=FALSE)[-1]) == "...")==FALSE){
+    if(length(args)==0){
 # Create vector of the errors
         if(any(randomizer==c("rnorm","runif"))){
             materrors[,] <- eval(parse(text=paste0(randomizer,"(n=",nsim*obs,")")));
@@ -252,7 +251,7 @@ sim.ces <- function(seasonality=c("none","simple","partial","full"),
     }
 # If arguments are passed, use them. WE ASSUME HERE THAT USER KNOWS WHAT HE'S DOING!
     else{
-        materrors[,] <- eval(parse(text=paste0(randomizer,"(n=",nsim*obs,",", toString(as.character(list(...))),")")));
+        materrors[,] <- eval(parse(text=paste0(randomizer,"(n=",nsim*obs,",", toString(as.character(args)),")")));
         if(randomizer=="rbeta"){
 # Center the errors around 0
             materrors <- materrors - 0.5;
